#
# spec file for package deepin-compressor
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?is_opensuse}
    %define  distribution  openSUSE-Edition
%else
    %define  distribution  SUSE-Edition
%endif

Name:           deepin-compressor
Version:        5.12.13
Release:        2.4
License:        GPL-3.0-or-later
Summary:        Archive Manager for Deepin Desktop
URL:            https://github.com/linuxdeepin/deepin-compressor
Group:          Productivity/Archiving/Compression
Source0:        https://github.com/linuxdeepin/deepin-compressor/archive/%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM 002-install-compressor-ChardetDetector.patch hillwood@opensuse.org
# Install libcompressor-ChardetDetector.so
Patch1:         002-install-compressor-ChardetDetector.patch
# PATCH-FIX-UPSTREAM fix-Zip-Path-Traversal.patch - fix Zip Path Traversal
# backport form https://github.com/linuxdeepin/deepin-compressor/commit/82f668c78c133873f5094cfab6e4eabc0b70e4b6
Patch2:         fix-Zip-Path-Traversal.patch
BuildRequires:  fdupes
BuildRequires:  gtest
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist
BuildRequires:  cmake(KF5Archive)
BuildRequires:  cmake(KF5Codecs)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(dtkwidget)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(minizip)
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Archive Manager is a fast and lightweight application for creating and
extracting archives.

%lang_package

%prep
%autosetup -p1
sed -i 's/lrelease/lrelease-qt5/g' src/translate_generation.sh
sed -i 's|/usr/lib/|%{_libdir}/|g' src/source/common/pluginmanager.cpp
%ifarch armv6l armv7l aarch64
sed -i '/#include <map>/a#include <cstdint>' tests/UnitTest/include/gtest/src/stub.h
%endif

%build
%cmake -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
       -DCMAKE_BUILD_TYPE=Release \
       -DAPP_VERSION=%{version}-%{distribution} \
       -DVERSION=%{version}-%{distribution}
%make_build

%install
%cmake_install

rm %{buildroot}%{_libdir}/deepin-compressor/plugins/libcompressor-ChardetDetector.a
chmod -x %{buildroot}%{_datadir}/applications/%{name}.desktop

%fdupes %{buildroot}%{_datadir}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/applications/context-menus
%{_datadir}/applications/context-menus/compressor-*.conf
%dir %{_datadir}/%{name}
%{_datadir}/deepin-manual
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/mime/packages/deepin-compressor.xml

%files lang
%{_datadir}/%{name}/translations

%changelog
* Thu Dec 28 2023 Hillwood Yang <hillwood@opensuse.org>
- Add fix-Zip-Path-Traversal.patch
  * Fix Zip Path Traversal (boo#1218428 and CVE-2023-50255)
* Mon Jan 16 2023 Dirk Müller <dmueller@suse.com>
- update to 5.12.13:
  * fix missing changelog
* Wed Dec  7 2022 Dirk Müller <dmueller@suse.com>
- update to 5.12.12:
  * see https://github.com/linuxdeepin/deepin-compressor/compare/5.12.8...5.12.12
* Thu Aug 25 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.12.8
  * Fix bugs
  * Support rename by right click
- Drop 001-fix-libdir.patch, fixed by upstream
* Sat Jul  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.12.6
  * Change qDebug to qInfo
* Thu Apr 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.12.5
  * Fix bugs
* Mon Mar 21 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on ARM.
* Sun Mar 20 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.12.2
  * Support long long filename
  * Support choosing 1, 2, 4, 8 CPU cores.
  * The minimum window size is 620*300
  * Update documents
  * Fix bugs
* Sun Feb 27 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.11.8
  * Fix bugs
  * Add UT script
* Mon Jan 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.11.7
  * Update manual documents
  * Fix bugs
* Fri Jul 30 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.10.5
  * Update manunal documents
  * Fix bugs
  * Add some test modules
  * Update translation
* Mon Apr 19 2021 Hillwood Yang <hillwood@opensuse.org>
- Initial package for version 5.10.0.15
- Add 001-fix-libdir.patch and 002-install-compressor-ChardetDetector.patch
